
/*
 * Module dependencies.
 */

var profanity = require('profanity-util')
var debug = require('debug')('simple-spam-filter')

/*
 * Checks if a given tweet is spam.
 * @param {number} minWords - the minimum number of words for the tweet
 * @param {number} maxPercentCaps - the percentage of characters that can be
 *                                  capitalized
 * @param {number} maxNumSwearWords - the maximum number of swear words in the
 *                                    tweet
 * @returns {boolean}
 * @api public
 */

function SimpleSpamFilter (opts) {
  this.minWords = opts.minWords
  this.maxPercentCaps = opts.maxPercentCaps
  this.maxNumSwearWords = opts.maxNumSwearWords
}

SimpleSpamFilter.prototype.isSpam = function (tweet) {
  if (this.minWords !== undefined &&
    tweet.split(' ').length < this.minWords) {
    debug('`%s` does not meet minimum word requirement', tweet)
    return true
  }

  if (this.maxPercentCaps !== undefined &&
    percentCaps(tweet) > this.maxPercentCaps) {
    debug('`%s` exceeds max percentage of capitalized characters', tweet)
    return true
  }

  if (this.maxNumSwearWords !== undefined &&
    numSwearWords(tweet) > this.maxNumSwearWords) {
    debug('`%s` exceeds max number of swear words', tweet)
    return true
  }

  debug('`%s` is not spam', tweet)
  return false
}

/*
 * Returns the percentage of the tweet that consists of capitalized characters.
 * @param tweet - the tweet to analyze
 * @returns {number}
 * @api private
 */

function percentCaps (tweet) {
  var capCount = 0
  var chars = tweet.split('')

  chars.forEach(function (char) {
    if (char === char.toUpperCase()) {
      capCount++
    }
  })

  return (capCount / tweet.length) * 100
}

/*
 * Returns the number of swear words in the tweet.
 * @param tweet - the tweet to analyze
 * @returns {number}
 * @api private
 */

function numSwearWords (tweet) {
  return profanity.check(tweet).length
}

/*
 * Module exports.
 */

module.exports = SimpleSpamFilter
